Image Process Changelog
=======================

This Changelog is for ``minchin.pelican.plugins.summary``.

- :release`1.2.1 <2023-08-09>`
- :bug:`-` blacklist ``autoloader`` v1.2.0
- :release`1.2.0 <2022-06-10>`
- :feature:`-` set up for autoloading
- :feature:`1` add support for Pelican 4. Thanks `Henry Swanson
  <https://github.com/HenrySwanson/>`_!
- :release:`1.1.1 <2017-04-18>`
- :bug:`-` add Pelican trove classifier
- :release:`1.1.0 <2017-01-29>`
- :support:`-` first release to PyPI
- :support:`-` add release machinery
- :support:`-` move package to ``minchin.pelican.plugins.summary``
- :release:`1.0.0 <2017-01-29>`
- :support:`-` extract existing code from
  https://github.com/getpelican/pelican-plugins
